@@ -12,7 +12,7 @@ from spider.elements.vehicle import VehicleState
 from spider.elements.Box import TrackingBoxList, TrackingBox
 
 from spider.sampler.PolynomialSampler import QuinticPolyminalSampler, QuarticPolyminalSampler
-from spider.sampler.Combiner import PVDCombiner
+from spider.sampler.Combiner import LatLonCombiner
 from spider.evaluator import FrenetCostEvaluator
 
 from spider.utils.transform.frenet import FrenetCoordinateTransformer
@@ -37,7 +37,7 @@ class LatticePlanner(BasicPlanner):
                                                             self.config["end_v_candidates"])
         self.lateral_sampler = QuinticPolyminalSampler(self.config["end_s_candidates"],
                                                        self.config["end_l_candidates"])
-        self.trajectory_combiner = PVDCombiner(self.config["steps"],self.config["dt"]) # 默认路径-速度解耦的重新耦合
+        self.trajectory_combiner = LatLonCombiner(self.config["steps"], self.config["dt"]) # 默认路径-速度解耦的重新耦合
         self.trajectory_evaluator = FrenetCostEvaluator()
 
         # self.collision_checker = BoxCollisionChecker(self.config["ego_veh_length"], self.config["ego_veh_width"])
@@ -45,6 +45,9 @@ class LatticePlanner(BasicPlanner):
             self.config, BoxCollisionChecker(self.config["ego_veh_length"], self.config["ego_veh_width"])
         )
 
+        self._candidate_trajectories = None
+        self._candidate_trajectories_cost = None
+
 
     @classmethod
     def default_config(cls) -> dict:
@@ -90,6 +93,10 @@ class LatticePlanner(BasicPlanner):
         # self.end_T_candidates = self.config["end_T_candidates"]
 
 
+    def get_candidate_traj_with_cost(self):
+        return self._candidate_trajectories, self._candidate_trajectories_cost
+
+
     def constraint_check(self, sorted_candidate_trajectories:List[FrenetTrajectory], sorted_cost, obstacles:TrackingBoxList):
         for traj, cost in zip(sorted_candidate_trajectories, sorted_cost):
             if self.constraint_checker.check(traj, obstacles):
@@ -165,6 +172,9 @@ class LatticePlanner(BasicPlanner):
         # 评估+筛选
         sorted_candidates, sorted_cost = self.trajectory_evaluator.evaluate_candidates(candidate_trajectories)
         optimal_trajectory, min_cost = self.constraint_check(sorted_candidates, sorted_cost, predicted_obstacles)
+
+        self._candidate_trajectories, self._candidate_trajectories_cost = sorted_candidates, sorted_cost
+
         if not (optimal_trajectory is None):
             print("Optimal trajectory found! s_dot_end=%.2f,l_end=%.2f" %
                   (optimal_trajectory.s_dot[-1], optimal_trajectory.l[-1]))
